@@ -1,31 +1,30 @@
 use crate::{
+    filehash::get_filehash,
     yubi,
     zfs::{zfs_create, zfs_mount},
 };
-use sha2::{Digest, Sha512};
-use std::{io::Read, process::exit};
 
-pub fn print_mode_yubi(pass: &String) {
-    let key = yubi::get_hash(&pass).expect("Failed to calculate hash from Yubikey"); // Get encryption key
+use sha2::{Digest, Sha512};
+use std::process::exit;
+
+pub fn print_mode_yubi(pass: &String,slot:u8) {
+    let key = yubi::get_hash(&pass,slot).expect("Failed to calculate hash from Yubikey"); // Get encryption key
     println!("{}", &key);
     exit(0);
 }
 
-pub fn print_mode_file(pass: &String, file: &String) {
-    let passhash = Sha512::digest(&pass.as_bytes());
+pub fn print_mode_file(pass: &String, file: &String, port: u16) {
+    let passhash = Sha512::digest(&pass.as_bytes()).to_vec();
 
-    let mut f = std::fs::File::open(&file).expect("Failed opening file");
-    let mut filehash: Vec<u8> = Vec::new();
-    f.read_to_end(&mut filehash).expect("Failed reading file.");
-    let filehash = Sha512::digest(&filehash);
+    let filehash = get_filehash(&file, port);
     let key = [filehash, passhash].concat();
     let key = Sha512::digest(&key);
     println!("{:x}", &key);
     exit(0);
 }
 
-pub fn unlock_zfs_yubi(pass: String, zfspath: String) {
-    let key = yubi::get_hash(&pass); // Get encryption key
+pub fn unlock_zfs_yubi(pass: String, zfspath: String,slot:u8) {
+    let key = yubi::get_hash(&pass,slot); // Get encryption key
     let mut zfspath = zfspath;
     match key {
         Ok(key) => {
@@ -40,42 +39,35 @@ pub fn unlock_zfs_yubi(pass: String, zfspath: String) {
     }
 }
 
-pub fn unlock_zfs_file(pass: String, file: String, dataset: String) {
+pub fn unlock_zfs_file(pass: String, file: String, dataset: String, port: u16) {
     let mut dataset = dataset;
     if dataset.ends_with("/") {
         dataset.pop();
     }
-    let passhash = Sha512::digest(&pass.as_bytes());
-
-    let mut f = std::fs::File::open(&file).expect("Failed opening file");
-    let mut filehash: Vec<u8> = Vec::new();
-    f.read_to_end(&mut filehash).expect("Failed reading file.");
-    let filehash = Sha512::digest(&filehash);
+    let passhash = Sha512::digest(&pass.as_bytes()).to_vec();
+    let filehash = get_filehash(&file, port);
     let key = [filehash, passhash].concat();
     let key = Sha512::digest(&key);
     let key = format!("{:x}", key);
     zfs_mount(&key, dataset)
 }
 
-pub fn create_zfs_file(pass: String, file: String, dataset: String) {
+pub fn create_zfs_file(pass: String, file: String, dataset: String, port: u16) {
     let mut dataset = dataset;
     if dataset.ends_with("/") {
         dataset.pop();
     }
-    let passhash = Sha512::digest(&pass.as_bytes());
+    let passhash = Sha512::digest(&pass.as_bytes()).to_vec();
 
-    let mut f = std::fs::File::open(&file).expect("Failed opening file");
-    let mut filehash: Vec<u8> = Vec::new();
-    f.read_to_end(&mut filehash).expect("Failed reading file.");
-    let filehash = Sha512::digest(&filehash);
+    let filehash = get_filehash(&file, port);
     let key = [filehash, passhash].concat();
     let key = Sha512::digest(&key);
     let key = format!("{:x}", key);
     zfs_create(&key, dataset)
 }
 
-pub fn create_zfs_yubi(pass: String, zfspath: String) {
-    let key = yubi::get_hash(&pass); // Get encryption key
+pub fn create_zfs_yubi(pass: String, zfspath: String,slot:u8) {
+    let key = yubi::get_hash(&pass,slot); // Get encryption key
     let mut zfspath = zfspath;
     match key {
         Ok(key) => {
@@ -89,3 +81,4 @@ pub fn create_zfs_yubi(pass: String, zfspath: String) {
         Err(error) => panic!("{}", error),
     }
 }
+
